@@ -1,19 +1,21 @@
-from .api import distribution, Distribution, PackageNotFoundError  # noqa: F401
 from .api import (
-    metadata, entry_points, version, files, requires, distributions,
-    )
+    Distribution, PackageNotFoundError, distribution, distributions,
+    entry_points, files, metadata, requires, version)
 
 # Import for installation side-effects.
 from . import _hooks  # noqa: F401
 
 
 __all__ = [
+    'Distribution',
+    'PackageNotFoundError',
+    'distribution',
+    'distributions',
     'entry_points',
     'files',
     'metadata',
     'requires',
     'version',
-    'distributions',
     ]
 
 
