@@ -15,13 +15,16 @@ from importlib import import_module
 from itertools import starmap
 
 if sys.version_info > (3,):  # pragma: nocover
-    import pathlib
     from configparser import ConfigParser
 else:  # pragma: nocover
-    import pathlib2 as pathlib
     from backports.configparser import ConfigParser
     from itertools import imap as map  # type: ignore
 
+if sys.version_info > (3, 5):  # pragma: nocover
+    import pathlib
+else:  # pragma: nocover
+    import pathlib2 as pathlib
+
 try:
     BaseClass = ModuleNotFoundError
 except NameError:                                 # pragma: nocover
@@ -195,7 +198,14 @@ class Distribution:
         The returned object will have keys that name the various bits of
         metadata.  See PEP 566 for details.
         """
-        text = self.read_text('METADATA') or self.read_text('PKG-INFO')
+        text = (
+            self.read_text('METADATA')
+            or self.read_text('PKG-INFO')
+            # This last clause is here to support old egg-info files.  Its
+            # effect is to just end up using the PathDistribution's self._path
+            # (which points to the egg-info file) attribute unchanged.
+            or self.read_text('')
+            )
         return _email_message_from_string(text)
 
     @property
@@ -246,7 +256,7 @@ class Distribution:
 
     def _read_egg_info_reqs(self):
         source = self.read_text('requires.txt')
-        return self._deps_from_requires_text(source)
+        return source and self._deps_from_requires_text(source)
 
     @classmethod
     def _deps_from_requires_text(cls, source):
